"use client";
import {
  NavigationMenu,
  NavigationMenuContent,
  NavigationMenuItem,
  NavigationMenuList,
  NavigationMenuTrigger,
} from "~/components/ui/navigation-menu";

import { Input } from "~/components/ui/input";
import { Slider } from "~/components/ui/slider";
import { ChangeEvent, useState } from "react";
import useFilterStore from "../store";

export default function Filtermenu() {
  const [minPrice, setMinPrice] = useState<number>(0);
  const [maxPrice, setMaxPrice] = useState<number>(9999);
  const [sliderValues, setSliderValues] = useState<[number, number]>([0, 9999]);
  const setStorePrice = useFilterStore((state) => state.setPrice);

  const handleMinPriceChange = (e: ChangeEvent<HTMLInputElement>): void => {
    const value = Math.min(Number(e.target.value), maxPrice - 1);
    setMinPrice(value);
    setSliderValues([value, sliderValues[1]]);
    setStorePrice(minPrice, maxPrice);
  };

  const handleMaxPriceChange = (e: ChangeEvent<HTMLInputElement>) => {
    const value = Math.max(Number(e.target.value), minPrice + 1);
    setMaxPrice(value);
    setSliderValues([sliderValues[0], value]);
    setStorePrice(minPrice, maxPrice);
  };

  const handleSliderChange = (values: [number, number]) => {
    setSliderValues(values);
    setMinPrice(values[0]);
    setMaxPrice(values[1]);
    setStorePrice(minPrice, maxPrice);
  };

  return (
    <div className="container flex justify-center gap-2">
      {/* TODO:
        Checkboxes instead of menuitems. Check boxes are added as badges under the search bar */}
      {/* Price filter */}
      <NavigationMenu>
        <NavigationMenuList>
          <NavigationMenuItem>
            <NavigationMenuTrigger>Price</NavigationMenuTrigger>
            <NavigationMenuContent className="min-w- flex overflow-auto p-2">
              <Input
                value={minPrice}
                onChange={handleMinPriceChange}
                className="min-w-20"
                type="number"
                defaultValue={0}
              />
              <Slider
                value={sliderValues}
                onValueChange={handleSliderChange}
                className="min-w-36"
                min={0}
                max={9999}
                defaultValue={[0, 9999]}
              />
              <Input
                value={maxPrice}
                onChange={handleMaxPriceChange}
                className="min-w-20"
                type="number"
                defaultValue={9999}
              />
            </NavigationMenuContent>
          </NavigationMenuItem>
        </NavigationMenuList>
      </NavigationMenu>
      <NavigationMenu>
        <NavigationMenuList>
          <NavigationMenuItem>
            <NavigationMenuTrigger>Type</NavigationMenuTrigger>
            <NavigationMenuContent>
              <p>Anything goes?</p>
            </NavigationMenuContent>
          </NavigationMenuItem>
        </NavigationMenuList>
      </NavigationMenu>
      {/* Producer filter */}
      <NavigationMenu>
        <NavigationMenuList>
          <NavigationMenuItem>
            <NavigationMenuTrigger>Producer</NavigationMenuTrigger>
            <NavigationMenuContent className="w-fit p-2">
              <Input placeholder="producer filter" />
              <ul>
                <li>checkboxes for producer filter</li>
              </ul>
            </NavigationMenuContent>
          </NavigationMenuItem>
        </NavigationMenuList>
      </NavigationMenu>
      {/* Country Filter */}
      <NavigationMenu>
        <NavigationMenuList>
          <NavigationMenuItem>
            <NavigationMenuTrigger>Producer</NavigationMenuTrigger>
            <NavigationMenuContent className="w-fit p-2">
              <ul>
                <li>ccountry filter</li>
              </ul>
            </NavigationMenuContent>
          </NavigationMenuItem>
        </NavigationMenuList>
      </NavigationMenu>
      {/* Region Filter */}
      <NavigationMenu>
        <NavigationMenuList>
          <NavigationMenuItem>
            <NavigationMenuTrigger>Region</NavigationMenuTrigger>
            <NavigationMenuContent className="w-fit p-2">
              <Input placeholder="producer filter" />
              <ul>
                <li>checkboxes for producer filter</li>
              </ul>
            </NavigationMenuContent>
          </NavigationMenuItem>
        </NavigationMenuList>
      </NavigationMenu>
    </div>
  );
}
